import {
  PostgresCheckApi,
  PostgresCheckApiHandlers,
} from '../generated/postgres-check-api/api';
import { MonitorController } from './controller/MonitorController';
import { CheckController } from './controller/CheckController';
import { QueryController } from './controller/QueryController';
import { AccountService } from './service/AccountService';
import { accountApiKey } from './auth';

export class Api extends PostgresCheckApi {
  constructor(
    private monitorController: MonitorController,
    private checkController: CheckController,
    private queryController: QueryController,
    private accountService: AccountService,
  ) {
    super();
  }

  handlers: Partial<PostgresCheckApiHandlers> = {
    createMonitor: accountApiKey(
      () => this.accountService,
      (account) => (event) =>
        this.monitorController.createMonitor(account, event),
    ),
    getMonitors: accountApiKey(
      () => this.accountService,
      (account) => (event) =>
        this.monitorController.getMonitors(account, event),
    ),
    getChecks: accountApiKey(
      () => this.accountService,
      (account) => (event) => this.checkController.getChecks(account, event),
    ),
    getQueries: accountApiKey(
      () => this.accountService,
      (account) => (event) => this.queryController.getQueries(account, event),
    ),
  };
}
