import { AccountService } from './service/AccountService';
import { Account } from '../generated/postgres-check-api/model';
import { APIGatewayEvent, APIGatewayProxyResult } from 'aws-lambda';

export function accountApiKey(
  getAccountService: () => AccountService,
  handler: (
    account: Account,
  ) => (event: APIGatewayEvent) => Promise<APIGatewayProxyResult>,
): (event: APIGatewayEvent) => Promise<APIGatewayProxyResult> {
  return async (event: APIGatewayEvent) => {
    const keyName = Object.keys(event.headers ?? {}).find(
      (it) => it.toLowerCase() === 'x-account-api-key',
    );
    const apiKey = keyName && event.headers[keyName];
    if (!apiKey) {
      return {
        statusCode: 401,
        body: JSON.stringify('Unauthorized'),
      };
    }
    const accountService = getAccountService();
    const account = await accountService.getAccount(apiKey);
    if (!account) {
      return {
        statusCode: 401,
        body: JSON.stringify('Unauthorized'),
      };
    }
    const response = await handler(account)(event);
    return response;
  };
}
