import { MonitorDatabaseService } from '../service/MonitorDatabaseService';
import { APIGatewayProxyEvent } from 'aws-lambda/trigger/api-gateway-proxy';
import { Account, Monitor } from '../../generated/postgres-check-api/model';
import { AccountService } from '../service/AccountService';

export class MonitorController {
  constructor(private monitorDatabaseService: MonitorDatabaseService) {}

  async createMonitor(account: Account, event: APIGatewayProxyEvent) {
    const monitor = JSON.parse(event.body) as Monitor;
    if (!monitor.name || !monitor.connectionString) {
      return {
        statusCode: 400,
        body: JSON.stringify({ message: 'Bad Request' }),
      };
    }
    const createdMonitor = await this.monitorDatabaseService.createMonitor(
      account,
      monitor,
    );
    if (!createdMonitor) {
      return {
        statusCode: 500,
        body: JSON.stringify({ message: 'Internal Server Error' }),
      };
    }
    return { statusCode: 201, body: JSON.stringify(createdMonitor) };
  }
  async getMonitors(account: Account, event: APIGatewayProxyEvent) {
    const monitors = await this.monitorDatabaseService.getMonitors(account);
    return { statusCode: 200, body: JSON.stringify(monitors) };
  }
}
