import {
  Account,
  Check,
  CheckCollection,
} from '../../../generated/postgres-check-api/model';
import { DynamoDBDocument } from '@aws-sdk/lib-dynamodb';
import { TableClient } from '@hexlabs/dynamo-ts';
import { checkTable } from '../../tables';

export class CheckQueryDatabase {
  constructor(
    documentClient: DynamoDBDocument,
    private checkTableClient = TableClient.build(checkTable, {
      tableName: 'postgres-check',
      client: documentClient,
      logStatements: false,
    }),
  ) {}

  async getChecks(
    account: Account,
    monitorId: string,
    date: string,
    next?: string,
  ): Promise<CheckCollection> {
    try {
      console.log('Getting checks from database');
      const {
        next: viewNext,
        member,
        count,
      } = await this.checkTableClient.query<Check>(
        {
          partitionKey: `#ACCOUNT-${account.email}#MONITOR-${monitorId}#${date}`,
        },
        { next: next },
      );
      console.log('Got checks from database');
      return {
        member: member,
        totalItems: count,
        view: viewNext ? { next: viewNext } : undefined,
      };
    } catch (error) {
      console.error('Getting checks from database failed', error);
    }
  }
}
