import {
  Account,
  MonitorCollection,
} from '../../../generated/postgres-check-api/model';
import { DynamoDBDocument } from '@aws-sdk/lib-dynamodb';
import { TableClient } from '@hexlabs/dynamo-ts';
import { monitorTable } from '../../tables';

export class MonitorQueryDatabase {
  constructor(
    documentClient: DynamoDBDocument,
    private monitorTableClient = TableClient.build(monitorTable, {
      tableName: 'postgres-check',
      client: documentClient,
      logStatements: false,
    }),
  ) {}

  async getMonitors(account: Account): Promise<MonitorCollection> {
    try {
      console.log('Getting monitors from database');

      const { member, count } = await this.monitorTableClient.queryAll({
        partitionKey: `#ACCOUNT-${account.email}`,
      });

      console.log('Got monitors from database');

      return {
        member: member,
        totalItems: count,
      };
    } catch (error) {
      console.error('Getting monitors from database failed', error);
    }
  }
}
