import { APIGatewayProxyEvent } from 'aws-lambda/trigger/api-gateway-proxy';
import { Api } from './Api';
import { DynamoDBDocument } from '@aws-sdk/lib-dynamodb';
import { DynamoDBClient } from '@aws-sdk/client-dynamodb';
import { MonitorController } from './controller/MonitorController';
import { MonitorDatabaseService } from './service/MonitorDatabaseService';
import { MonitorQueryDatabase } from './database/query/MonitorQueryDatabase';
import { CheckController } from './controller/CheckController';
import { QueryController } from './controller/QueryController';
import { CheckDatabaseService } from './service/CheckDatabaseService';
import { CheckQueryDatabase } from './database/query/CheckQueryDatabase';
import { QueryDatabaseService } from './service/QueryDatabaseService';
import { QueryQueryDatabase } from './database/query/QueryQueryDatabase';
import { AccountService } from './service/AccountService';
import { MonitorCommandDatabase } from './database/command/MonitorCommandDatabase';

const dynamoDBClient = new DynamoDBClient({ region: 'eu-west-1' });
const documentClient = DynamoDBDocument.from(dynamoDBClient, {
  marshallOptions: {
    removeUndefinedValues: true,
  },
});

const monitorController = new MonitorController(
  new MonitorDatabaseService(
    new MonitorCommandDatabase(documentClient),
    new MonitorQueryDatabase(documentClient),
  ),
);

const checkController = new CheckController(
  new CheckDatabaseService(new CheckQueryDatabase(documentClient)),
);

const queryController = new QueryController(
  new QueryDatabaseService(new QueryQueryDatabase(documentClient)),
);

const accountService = new AccountService();

export const api = new Api(
  monitorController,
  checkController,
  queryController,
  accountService,
);

export async function handler(event: APIGatewayProxyEvent) {
  return await api.handle(event);
}
